# flake8: noqa

# Registry keys

EVALUATOR = 'EVALUATOR'

OBJECT_DETECTION_EVALUATOR = 'OBJECT_DETECTION_EVALUATOR'
CHIP_CLASSIFICATION_EVALUATOR = 'CHIP_CLASSIFICATION_EVALUATOR'
SEMANTIC_SEGMENTATION_EVALUATOR = 'SEMANTIC_SEGMENTATION_EVALUATOR'

from rastervision.evaluation.evaluator_config import EvaluatorConfig
