# flake8: noqa

# Registry Keys

TASK = 'TASK'

OBJECT_DETECTION = 'OBJECT_DETECTION'
CHIP_CLASSIFICATION = 'CHIP_CLASSIFICATION'
SEMANTIC_SEGMENTATION = 'SEMANTIC_SEGMENTATION'

from .task_config import TaskConfig
