# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rastervision/protos/tf_object_detection/post_processing.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rastervision/protos/tf_object_detection/post_processing.proto',
  package='rastervision.protos.tf_object_detection',
  syntax='proto2',
  serialized_pb=_b('\n=rastervision/protos/tf_object_detection/post_processing.proto\x12\'rastervision.protos.tf_object_detection\"\xbc\x01\n\x16\x42\x61tchNonMaxSuppression\x12\x1a\n\x0fscore_threshold\x18\x01 \x01(\x02:\x01\x30\x12\x1a\n\riou_threshold\x18\x02 \x01(\x02:\x03\x30.6\x12%\n\x18max_detections_per_class\x18\x03 \x01(\x05:\x03\x31\x30\x30\x12!\n\x14max_total_detections\x18\x05 \x01(\x05:\x03\x31\x30\x30\x12 \n\x11use_static_shapes\x18\x06 \x01(\x08:\x05\x66\x61lse\"\xb1\x02\n\x0ePostProcessing\x12\x62\n\x19\x62\x61tch_non_max_suppression\x18\x01 \x01(\x0b\x32?.rastervision.protos.tf_object_detection.BatchNonMaxSuppression\x12i\n\x0fscore_converter\x18\x02 \x01(\x0e\x32\x46.rastervision.protos.tf_object_detection.PostProcessing.ScoreConverter:\x08IDENTITY\x12\x16\n\x0blogit_scale\x18\x03 \x01(\x02:\x01\x31\"8\n\x0eScoreConverter\x12\x0c\n\x08IDENTITY\x10\x00\x12\x0b\n\x07SIGMOID\x10\x01\x12\x0b\n\x07SOFTMAX\x10\x02')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_POSTPROCESSING_SCORECONVERTER = _descriptor.EnumDescriptor(
  name='ScoreConverter',
  full_name='rastervision.protos.tf_object_detection.PostProcessing.ScoreConverter',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IDENTITY', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIGMOID', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SOFTMAX', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=547,
  serialized_end=603,
)
_sym_db.RegisterEnumDescriptor(_POSTPROCESSING_SCORECONVERTER)


_BATCHNONMAXSUPPRESSION = _descriptor.Descriptor(
  name='BatchNonMaxSuppression',
  full_name='rastervision.protos.tf_object_detection.BatchNonMaxSuppression',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='score_threshold', full_name='rastervision.protos.tf_object_detection.BatchNonMaxSuppression.score_threshold', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='iou_threshold', full_name='rastervision.protos.tf_object_detection.BatchNonMaxSuppression.iou_threshold', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0.6),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_detections_per_class', full_name='rastervision.protos.tf_object_detection.BatchNonMaxSuppression.max_detections_per_class', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=100,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_total_detections', full_name='rastervision.protos.tf_object_detection.BatchNonMaxSuppression.max_total_detections', index=3,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=100,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='use_static_shapes', full_name='rastervision.protos.tf_object_detection.BatchNonMaxSuppression.use_static_shapes', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=107,
  serialized_end=295,
)


_POSTPROCESSING = _descriptor.Descriptor(
  name='PostProcessing',
  full_name='rastervision.protos.tf_object_detection.PostProcessing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='batch_non_max_suppression', full_name='rastervision.protos.tf_object_detection.PostProcessing.batch_non_max_suppression', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='score_converter', full_name='rastervision.protos.tf_object_detection.PostProcessing.score_converter', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='logit_scale', full_name='rastervision.protos.tf_object_detection.PostProcessing.logit_scale', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _POSTPROCESSING_SCORECONVERTER,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=298,
  serialized_end=603,
)

_POSTPROCESSING.fields_by_name['batch_non_max_suppression'].message_type = _BATCHNONMAXSUPPRESSION
_POSTPROCESSING.fields_by_name['score_converter'].enum_type = _POSTPROCESSING_SCORECONVERTER
_POSTPROCESSING_SCORECONVERTER.containing_type = _POSTPROCESSING
DESCRIPTOR.message_types_by_name['BatchNonMaxSuppression'] = _BATCHNONMAXSUPPRESSION
DESCRIPTOR.message_types_by_name['PostProcessing'] = _POSTPROCESSING

BatchNonMaxSuppression = _reflection.GeneratedProtocolMessageType('BatchNonMaxSuppression', (_message.Message,), dict(
  DESCRIPTOR = _BATCHNONMAXSUPPRESSION,
  __module__ = 'rastervision.protos.tf_object_detection.post_processing_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.BatchNonMaxSuppression)
  ))
_sym_db.RegisterMessage(BatchNonMaxSuppression)

PostProcessing = _reflection.GeneratedProtocolMessageType('PostProcessing', (_message.Message,), dict(
  DESCRIPTOR = _POSTPROCESSING,
  __module__ = 'rastervision.protos.tf_object_detection.post_processing_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.PostProcessing)
  ))
_sym_db.RegisterMessage(PostProcessing)


# @@protoc_insertion_point(module_scope)
