# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rastervision/protos/keras_classification/optimizer.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rastervision/protos/keras_classification/optimizer.proto',
  package='keras_classification.protos',
  syntax='proto2',
  serialized_pb=_b('\n8rastervision/protos/keras_classification/optimizer.proto\x12\x1bkeras_classification.protos\"r\n\tOptimizer\x12\x39\n\x04type\x18\x04 \x02(\x0e\x32+.keras_classification.protos.Optimizer.Type\x12\x0f\n\x07init_lr\x18\x05 \x02(\x02\"\x19\n\x04Type\x12\x08\n\x04\x41\x44\x41M\x10\x01\x12\x07\n\x03SGD\x10\x02')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_OPTIMIZER_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='keras_classification.protos.Optimizer.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADAM', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SGD', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=178,
  serialized_end=203,
)
_sym_db.RegisterEnumDescriptor(_OPTIMIZER_TYPE)


_OPTIMIZER = _descriptor.Descriptor(
  name='Optimizer',
  full_name='keras_classification.protos.Optimizer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='keras_classification.protos.Optimizer.type', index=0,
      number=4, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='init_lr', full_name='keras_classification.protos.Optimizer.init_lr', index=1,
      number=5, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OPTIMIZER_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=203,
)

_OPTIMIZER.fields_by_name['type'].enum_type = _OPTIMIZER_TYPE
_OPTIMIZER_TYPE.containing_type = _OPTIMIZER
DESCRIPTOR.message_types_by_name['Optimizer'] = _OPTIMIZER

Optimizer = _reflection.GeneratedProtocolMessageType('Optimizer', (_message.Message,), dict(
  DESCRIPTOR = _OPTIMIZER,
  __module__ = 'rastervision.protos.keras_classification.optimizer_pb2'
  # @@protoc_insertion_point(class_scope:keras_classification.protos.Optimizer)
  ))
_sym_db.RegisterMessage(Optimizer)


# @@protoc_insertion_point(module_scope)
