# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rastervision/protos/evaluator.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rastervision.protos import class_item_pb2 as rastervision_dot_protos_dot_class__item__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rastervision/protos/evaluator.proto',
  package='rv.protos',
  syntax='proto2',
  serialized_pb=_b('\n#rastervision/protos/evaluator.proto\x12\trv.protos\x1a$rastervision/protos/class_item.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xc5\x02\n\x0f\x45valuatorConfig\x12\x16\n\x0e\x65valuator_type\x18\x01 \x02(\t\x12Y\n\x15\x63lassification_config\x18\x02 \x01(\x0b\x32\x38.rv.protos.EvaluatorConfig.ClassificationEvaluatorConfigH\x00\x12\x30\n\rcustom_config\x18\x03 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x1ay\n\x1d\x43lassificationEvaluatorConfig\x12\x12\n\noutput_uri\x18\x01 \x02(\t\x12\x19\n\x11vector_output_uri\x18\x03 \x01(\t\x12)\n\x0b\x63lass_items\x18\x02 \x03(\x0b\x32\x14.rv.protos.ClassItemB\x12\n\x10\x65valuator_config')
  ,
  dependencies=[rastervision_dot_protos_dot_class__item__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_EVALUATORCONFIG_CLASSIFICATIONEVALUATORCONFIG = _descriptor.Descriptor(
  name='ClassificationEvaluatorConfig',
  full_name='rv.protos.EvaluatorConfig.ClassificationEvaluatorConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_uri', full_name='rv.protos.EvaluatorConfig.ClassificationEvaluatorConfig.output_uri', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vector_output_uri', full_name='rv.protos.EvaluatorConfig.ClassificationEvaluatorConfig.vector_output_uri', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='class_items', full_name='rv.protos.EvaluatorConfig.ClassificationEvaluatorConfig.class_items', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=303,
  serialized_end=424,
)

_EVALUATORCONFIG = _descriptor.Descriptor(
  name='EvaluatorConfig',
  full_name='rv.protos.EvaluatorConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='evaluator_type', full_name='rv.protos.EvaluatorConfig.evaluator_type', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='classification_config', full_name='rv.protos.EvaluatorConfig.classification_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='custom_config', full_name='rv.protos.EvaluatorConfig.custom_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_EVALUATORCONFIG_CLASSIFICATIONEVALUATORCONFIG, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='evaluator_config', full_name='rv.protos.EvaluatorConfig.evaluator_config',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=119,
  serialized_end=444,
)

_EVALUATORCONFIG_CLASSIFICATIONEVALUATORCONFIG.fields_by_name['class_items'].message_type = rastervision_dot_protos_dot_class__item__pb2._CLASSITEM
_EVALUATORCONFIG_CLASSIFICATIONEVALUATORCONFIG.containing_type = _EVALUATORCONFIG
_EVALUATORCONFIG.fields_by_name['classification_config'].message_type = _EVALUATORCONFIG_CLASSIFICATIONEVALUATORCONFIG
_EVALUATORCONFIG.fields_by_name['custom_config'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_EVALUATORCONFIG.oneofs_by_name['evaluator_config'].fields.append(
  _EVALUATORCONFIG.fields_by_name['classification_config'])
_EVALUATORCONFIG.fields_by_name['classification_config'].containing_oneof = _EVALUATORCONFIG.oneofs_by_name['evaluator_config']
_EVALUATORCONFIG.oneofs_by_name['evaluator_config'].fields.append(
  _EVALUATORCONFIG.fields_by_name['custom_config'])
_EVALUATORCONFIG.fields_by_name['custom_config'].containing_oneof = _EVALUATORCONFIG.oneofs_by_name['evaluator_config']
DESCRIPTOR.message_types_by_name['EvaluatorConfig'] = _EVALUATORCONFIG

EvaluatorConfig = _reflection.GeneratedProtocolMessageType('EvaluatorConfig', (_message.Message,), dict(

  ClassificationEvaluatorConfig = _reflection.GeneratedProtocolMessageType('ClassificationEvaluatorConfig', (_message.Message,), dict(
    DESCRIPTOR = _EVALUATORCONFIG_CLASSIFICATIONEVALUATORCONFIG,
    __module__ = 'rastervision.protos.evaluator_pb2'
    # @@protoc_insertion_point(class_scope:rv.protos.EvaluatorConfig.ClassificationEvaluatorConfig)
    ))
  ,
  DESCRIPTOR = _EVALUATORCONFIG,
  __module__ = 'rastervision.protos.evaluator_pb2'
  # @@protoc_insertion_point(class_scope:rv.protos.EvaluatorConfig)
  ))
_sym_db.RegisterMessage(EvaluatorConfig)
_sym_db.RegisterMessage(EvaluatorConfig.ClassificationEvaluatorConfig)


# @@protoc_insertion_point(module_scope)
