# flake8: noqa

# Registry Keys

RASTER_TRANSFORMER = 'RASTER_TRANSFORMER'

CHANNEL_TRANSFORMER = 'CHANNEL_TRANSFORMER'
STATS_TRANSFORMER = 'STATS_TRANSFORMER'

from rastervision.data.raster_transformer.raster_transformer_config \
    import RasterTransformerConfig
