# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rastervision/protos/tf_object_detection/pipeline.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rastervision.protos.tf_object_detection import eval_pb2 as rastervision_dot_protos_dot_tf__object__detection_dot_eval__pb2
from rastervision.protos.tf_object_detection import graph_rewriter_pb2 as rastervision_dot_protos_dot_tf__object__detection_dot_graph__rewriter__pb2
from rastervision.protos.tf_object_detection import input_reader_pb2 as rastervision_dot_protos_dot_tf__object__detection_dot_input__reader__pb2
from rastervision.protos.tf_object_detection import model_pb2 as rastervision_dot_protos_dot_tf__object__detection_dot_model__pb2
from rastervision.protos.tf_object_detection import train_pb2 as rastervision_dot_protos_dot_tf__object__detection_dot_train__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rastervision/protos/tf_object_detection/pipeline.proto',
  package='rastervision.protos.tf_object_detection',
  syntax='proto2',
  serialized_pb=_b('\n6rastervision/protos/tf_object_detection/pipeline.proto\x12\'rastervision.protos.tf_object_detection\x1a\x32rastervision/protos/tf_object_detection/eval.proto\x1a<rastervision/protos/tf_object_detection/graph_rewriter.proto\x1a:rastervision/protos/tf_object_detection/input_reader.proto\x1a\x33rastervision/protos/tf_object_detection/model.proto\x1a\x33rastervision/protos/tf_object_detection/train.proto\"\xf5\x03\n\x17TrainEvalPipelineConfig\x12\x46\n\x05model\x18\x01 \x01(\x0b\x32\x37.rastervision.protos.tf_object_detection.DetectionModel\x12J\n\x0ctrain_config\x18\x02 \x01(\x0b\x32\x34.rastervision.protos.tf_object_detection.TrainConfig\x12P\n\x12train_input_reader\x18\x03 \x01(\x0b\x32\x34.rastervision.protos.tf_object_detection.InputReader\x12H\n\x0b\x65val_config\x18\x04 \x01(\x0b\x32\x33.rastervision.protos.tf_object_detection.EvalConfig\x12O\n\x11\x65val_input_reader\x18\x05 \x03(\x0b\x32\x34.rastervision.protos.tf_object_detection.InputReader\x12N\n\x0egraph_rewriter\x18\x06 \x01(\x0b\x32\x36.rastervision.protos.tf_object_detection.GraphRewriter*\t\x08\xe8\x07\x10\x80\x80\x80\x80\x02')
  ,
  dependencies=[rastervision_dot_protos_dot_tf__object__detection_dot_eval__pb2.DESCRIPTOR,rastervision_dot_protos_dot_tf__object__detection_dot_graph__rewriter__pb2.DESCRIPTOR,rastervision_dot_protos_dot_tf__object__detection_dot_input__reader__pb2.DESCRIPTOR,rastervision_dot_protos_dot_tf__object__detection_dot_model__pb2.DESCRIPTOR,rastervision_dot_protos_dot_tf__object__detection_dot_train__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_TRAINEVALPIPELINECONFIG = _descriptor.Descriptor(
  name='TrainEvalPipelineConfig',
  full_name='rastervision.protos.tf_object_detection.TrainEvalPipelineConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='model', full_name='rastervision.protos.tf_object_detection.TrainEvalPipelineConfig.model', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='train_config', full_name='rastervision.protos.tf_object_detection.TrainEvalPipelineConfig.train_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='train_input_reader', full_name='rastervision.protos.tf_object_detection.TrainEvalPipelineConfig.train_input_reader', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='eval_config', full_name='rastervision.protos.tf_object_detection.TrainEvalPipelineConfig.eval_config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='eval_input_reader', full_name='rastervision.protos.tf_object_detection.TrainEvalPipelineConfig.eval_input_reader', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='graph_rewriter', full_name='rastervision.protos.tf_object_detection.TrainEvalPipelineConfig.graph_rewriter', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(1000, 536870912), ],
  oneofs=[
  ],
  serialized_start=380,
  serialized_end=881,
)

_TRAINEVALPIPELINECONFIG.fields_by_name['model'].message_type = rastervision_dot_protos_dot_tf__object__detection_dot_model__pb2._DETECTIONMODEL
_TRAINEVALPIPELINECONFIG.fields_by_name['train_config'].message_type = rastervision_dot_protos_dot_tf__object__detection_dot_train__pb2._TRAINCONFIG
_TRAINEVALPIPELINECONFIG.fields_by_name['train_input_reader'].message_type = rastervision_dot_protos_dot_tf__object__detection_dot_input__reader__pb2._INPUTREADER
_TRAINEVALPIPELINECONFIG.fields_by_name['eval_config'].message_type = rastervision_dot_protos_dot_tf__object__detection_dot_eval__pb2._EVALCONFIG
_TRAINEVALPIPELINECONFIG.fields_by_name['eval_input_reader'].message_type = rastervision_dot_protos_dot_tf__object__detection_dot_input__reader__pb2._INPUTREADER
_TRAINEVALPIPELINECONFIG.fields_by_name['graph_rewriter'].message_type = rastervision_dot_protos_dot_tf__object__detection_dot_graph__rewriter__pb2._GRAPHREWRITER
DESCRIPTOR.message_types_by_name['TrainEvalPipelineConfig'] = _TRAINEVALPIPELINECONFIG

TrainEvalPipelineConfig = _reflection.GeneratedProtocolMessageType('TrainEvalPipelineConfig', (_message.Message,), dict(
  DESCRIPTOR = _TRAINEVALPIPELINECONFIG,
  __module__ = 'rastervision.protos.tf_object_detection.pipeline_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.TrainEvalPipelineConfig)
  ))
_sym_db.RegisterMessage(TrainEvalPipelineConfig)


# @@protoc_insertion_point(module_scope)
