# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rastervision/protos/tf_object_detection/matcher.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rastervision.protos.tf_object_detection import argmax_matcher_pb2 as rastervision_dot_protos_dot_tf__object__detection_dot_argmax__matcher__pb2
from rastervision.protos.tf_object_detection import bipartite_matcher_pb2 as rastervision_dot_protos_dot_tf__object__detection_dot_bipartite__matcher__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rastervision/protos/tf_object_detection/matcher.proto',
  package='rastervision.protos.tf_object_detection',
  syntax='proto2',
  serialized_pb=_b('\n5rastervision/protos/tf_object_detection/matcher.proto\x12\'rastervision.protos.tf_object_detection\x1a<rastervision/protos/tf_object_detection/argmax_matcher.proto\x1a?rastervision/protos/tf_object_detection/bipartite_matcher.proto\"\xc4\x01\n\x07Matcher\x12P\n\x0e\x61rgmax_matcher\x18\x01 \x01(\x0b\x32\x36.rastervision.protos.tf_object_detection.ArgMaxMatcherH\x00\x12V\n\x11\x62ipartite_matcher\x18\x02 \x01(\x0b\x32\x39.rastervision.protos.tf_object_detection.BipartiteMatcherH\x00\x42\x0f\n\rmatcher_oneof')
  ,
  dependencies=[rastervision_dot_protos_dot_tf__object__detection_dot_argmax__matcher__pb2.DESCRIPTOR,rastervision_dot_protos_dot_tf__object__detection_dot_bipartite__matcher__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_MATCHER = _descriptor.Descriptor(
  name='Matcher',
  full_name='rastervision.protos.tf_object_detection.Matcher',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='argmax_matcher', full_name='rastervision.protos.tf_object_detection.Matcher.argmax_matcher', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bipartite_matcher', full_name='rastervision.protos.tf_object_detection.Matcher.bipartite_matcher', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='matcher_oneof', full_name='rastervision.protos.tf_object_detection.Matcher.matcher_oneof',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=226,
  serialized_end=422,
)

_MATCHER.fields_by_name['argmax_matcher'].message_type = rastervision_dot_protos_dot_tf__object__detection_dot_argmax__matcher__pb2._ARGMAXMATCHER
_MATCHER.fields_by_name['bipartite_matcher'].message_type = rastervision_dot_protos_dot_tf__object__detection_dot_bipartite__matcher__pb2._BIPARTITEMATCHER
_MATCHER.oneofs_by_name['matcher_oneof'].fields.append(
  _MATCHER.fields_by_name['argmax_matcher'])
_MATCHER.fields_by_name['argmax_matcher'].containing_oneof = _MATCHER.oneofs_by_name['matcher_oneof']
_MATCHER.oneofs_by_name['matcher_oneof'].fields.append(
  _MATCHER.fields_by_name['bipartite_matcher'])
_MATCHER.fields_by_name['bipartite_matcher'].containing_oneof = _MATCHER.oneofs_by_name['matcher_oneof']
DESCRIPTOR.message_types_by_name['Matcher'] = _MATCHER

Matcher = _reflection.GeneratedProtocolMessageType('Matcher', (_message.Message,), dict(
  DESCRIPTOR = _MATCHER,
  __module__ = 'rastervision.protos.tf_object_detection.matcher_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.Matcher)
  ))
_sym_db.RegisterMessage(Matcher)


# @@protoc_insertion_point(module_scope)
