# flake8: noqa

# Registry keys

BACKEND = 'BACKEND'

## Backend Keys

TF_OBJECT_DETECTION = 'TF_OBJECT_DETECTION'
KERAS_CLASSIFICATION = 'KERAS_CLASSIFICATION'
TF_DEEPLAB = 'TF_DEEPLAB'

PYTORCH_SEMANTIC_SEGMENTATION = 'PYTORCH_SEMANTIC_SEGMENTATION'
PYTORCH_CHIP_CLASSIFICATION = 'PYTORCH_CHIP_CLASSIFICATION'
PYTORCH_OBJECT_DETECTION = 'PYTORCH_OBJECT_DETECTION'

## Model keys

### TF Object Detection
SSD_MOBILENET_V1_COCO = 'SSD_MOBILENET_V1_COCO'
SSD_MOBILENET_V2_COCO = 'SSD_MOBILENET_V2_COCO'
SSDLITE_MOBILENET_V2_COCO = 'SSDLITE_MOBILENET_V2_COCO'
SSD_INCEPTION_V2_COCO = 'SSD_INCEPTION_V2_COCO'
FASTER_RCNN_INCEPTION_V2_COCO = 'FASTER_RCNN_INCEPTION_V2_COCO'
FASTER_RCNN_RESNET50_COCO = 'FASTER_RCNN_RESNET50_COCO'
RFCN_RESNET101_COCO = 'RFCN_RESNET101_COCO'
FASTER_RCNN_RESNET101_COCO = 'FASTER_RCNN_RESNET101_COCO'
FASTER_RCNN_INCEPTION_RESNET_V2_ATROUS_COCO = \
'FASTER_RCNN_INCEPTION_RESNET_V2_ATROUS_COCO'
MASK_RCNN_INCEPTION_RESNET_V2_ATROUS_COCO = \
'MASK_RCNN_INCEPTION_RESNET_V2_ATROUS_COCO'
MASK_RCNN_INCEPTION_V2_COCO = 'MASK_RCNN_INCEPTION_V2_COCO'
MASK_RCNN_RESNET101_ATROUS_COCO = 'MASK_RCNN_RESNET101_ATROUS_COCO'
MASK_RCNN_RESNET50_ATROUS_COCO = 'MASK_RCNN_RESNET50_ATROUS_COCO'

## Keras Classificaiton
RESNET50_IMAGENET = 'RESNET50_IMAGENET'

# TF Deeplab
XCEPTION_65 = 'XCEPTION_65'
MOBILENET_V2 = 'MOBILENET_V2'

from .backend_config import BackendConfig
