# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rastervision/protos/tf_object_detection/ssd.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from rastervision.protos.tf_object_detection import anchor_generator_pb2 as rastervision_dot_protos_dot_tf__object__detection_dot_anchor__generator__pb2
from rastervision.protos.tf_object_detection import box_coder_pb2 as rastervision_dot_protos_dot_tf__object__detection_dot_box__coder__pb2
from rastervision.protos.tf_object_detection import box_predictor_pb2 as rastervision_dot_protos_dot_tf__object__detection_dot_box__predictor__pb2
from rastervision.protos.tf_object_detection import hyperparams_pb2 as rastervision_dot_protos_dot_tf__object__detection_dot_hyperparams__pb2
from rastervision.protos.tf_object_detection import image_resizer_pb2 as rastervision_dot_protos_dot_tf__object__detection_dot_image__resizer__pb2
from rastervision.protos.tf_object_detection import matcher_pb2 as rastervision_dot_protos_dot_tf__object__detection_dot_matcher__pb2
from rastervision.protos.tf_object_detection import losses_pb2 as rastervision_dot_protos_dot_tf__object__detection_dot_losses__pb2
from rastervision.protos.tf_object_detection import post_processing_pb2 as rastervision_dot_protos_dot_tf__object__detection_dot_post__processing__pb2
from rastervision.protos.tf_object_detection import region_similarity_calculator_pb2 as rastervision_dot_protos_dot_tf__object__detection_dot_region__similarity__calculator__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rastervision/protos/tf_object_detection/ssd.proto',
  package='rastervision.protos.tf_object_detection',
  syntax='proto2',
  serialized_pb=_b('\n1rastervision/protos/tf_object_detection/ssd.proto\x12\'rastervision.protos.tf_object_detection\x1a>rastervision/protos/tf_object_detection/anchor_generator.proto\x1a\x37rastervision/protos/tf_object_detection/box_coder.proto\x1a;rastervision/protos/tf_object_detection/box_predictor.proto\x1a\x39rastervision/protos/tf_object_detection/hyperparams.proto\x1a;rastervision/protos/tf_object_detection/image_resizer.proto\x1a\x35rastervision/protos/tf_object_detection/matcher.proto\x1a\x34rastervision/protos/tf_object_detection/losses.proto\x1a=rastervision/protos/tf_object_detection/post_processing.proto\x1aJrastervision/protos/tf_object_detection/region_similarity_calculator.proto\"\x94\t\n\x03Ssd\x12\x13\n\x0bnum_classes\x18\x01 \x01(\x05\x12L\n\rimage_resizer\x18\x02 \x01(\x0b\x32\x35.rastervision.protos.tf_object_detection.ImageResizer\x12W\n\x11\x66\x65\x61ture_extractor\x18\x03 \x01(\x0b\x32<.rastervision.protos.tf_object_detection.SsdFeatureExtractor\x12\x44\n\tbox_coder\x18\x04 \x01(\x0b\x32\x31.rastervision.protos.tf_object_detection.BoxCoder\x12\x41\n\x07matcher\x18\x05 \x01(\x0b\x32\x30.rastervision.protos.tf_object_detection.Matcher\x12\x62\n\x15similarity_calculator\x18\x06 \x01(\x0b\x32\x43.rastervision.protos.tf_object_detection.RegionSimilarityCalculator\x12)\n\x1a\x65ncode_background_as_zeros\x18\x0c \x01(\x08:\x05\x66\x61lse\x12 \n\x15negative_class_weight\x18\r \x01(\x02:\x01\x31\x12L\n\rbox_predictor\x18\x07 \x01(\x0b\x32\x35.rastervision.protos.tf_object_detection.BoxPredictor\x12R\n\x10\x61nchor_generator\x18\x08 \x01(\x0b\x32\x38.rastervision.protos.tf_object_detection.AnchorGenerator\x12P\n\x0fpost_processing\x18\t \x01(\x0b\x32\x37.rastervision.protos.tf_object_detection.PostProcessing\x12+\n\x1dnormalize_loss_by_num_matches\x18\n \x01(\x08:\x04true\x12-\n\x1enormalize_loc_loss_by_codesize\x18\x0e \x01(\x08:\x05\x66\x61lse\x12;\n\x04loss\x18\x0b \x01(\x0b\x32-.rastervision.protos.tf_object_detection.Loss\x12\x1f\n\x10\x66reeze_batchnorm\x18\x10 \x01(\x08:\x05\x66\x61lse\x12\'\n\x18inplace_batchnorm_update\x18\x0f \x01(\x08:\x05\x66\x61lse\x12.\n\x1fweight_regression_loss_by_score\x18\x11 \x01(\x08:\x05\x66\x61lse\x12>\n/use_expected_classification_loss_under_sampling\x18\x12 \x01(\x08:\x05\x66\x61lse\x12$\n\x19minimum_negative_sampling\x18\x13 \x01(\x02:\x01\x30\x12*\n\x1f\x64\x65sired_negative_sampling_ratio\x18\x14 \x01(\x02:\x01\x33\"\x96\x03\n\x13SsdFeatureExtractor\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x1b\n\x10\x64\x65pth_multiplier\x18\x02 \x01(\x02:\x01\x31\x12\x15\n\tmin_depth\x18\x03 \x01(\x05:\x02\x31\x36\x12N\n\x10\x63onv_hyperparams\x18\x04 \x01(\x0b\x32\x34.rastervision.protos.tf_object_detection.Hyperparams\x12:\n+override_base_feature_extractor_hyperparams\x18\t \x01(\x08:\x05\x66\x61lse\x12\x1a\n\x0fpad_to_multiple\x18\x05 \x01(\x05:\x01\x31\x12#\n\x14use_explicit_padding\x18\x07 \x01(\x08:\x05\x66\x61lse\x12\x1c\n\ruse_depthwise\x18\x08 \x01(\x08:\x05\x66\x61lse\x12L\n\x03\x66pn\x18\n \x01(\x0b\x32?.rastervision.protos.tf_object_detection.FeaturePyramidNetworksJ\x04\x08\x06\x10\x07\"i\n\x16\x46\x65\x61turePyramidNetworks\x12\x14\n\tmin_level\x18\x01 \x01(\x05:\x01\x33\x12\x14\n\tmax_level\x18\x02 \x01(\x05:\x01\x37\x12#\n\x16\x61\x64\x64itional_layer_depth\x18\x03 \x01(\x05:\x03\x32\x35\x36')
  ,
  dependencies=[rastervision_dot_protos_dot_tf__object__detection_dot_anchor__generator__pb2.DESCRIPTOR,rastervision_dot_protos_dot_tf__object__detection_dot_box__coder__pb2.DESCRIPTOR,rastervision_dot_protos_dot_tf__object__detection_dot_box__predictor__pb2.DESCRIPTOR,rastervision_dot_protos_dot_tf__object__detection_dot_hyperparams__pb2.DESCRIPTOR,rastervision_dot_protos_dot_tf__object__detection_dot_image__resizer__pb2.DESCRIPTOR,rastervision_dot_protos_dot_tf__object__detection_dot_matcher__pb2.DESCRIPTOR,rastervision_dot_protos_dot_tf__object__detection_dot_losses__pb2.DESCRIPTOR,rastervision_dot_protos_dot_tf__object__detection_dot_post__processing__pb2.DESCRIPTOR,rastervision_dot_protos_dot_tf__object__detection_dot_region__similarity__calculator__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_SSD = _descriptor.Descriptor(
  name='Ssd',
  full_name='rastervision.protos.tf_object_detection.Ssd',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_classes', full_name='rastervision.protos.tf_object_detection.Ssd.num_classes', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='image_resizer', full_name='rastervision.protos.tf_object_detection.Ssd.image_resizer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='feature_extractor', full_name='rastervision.protos.tf_object_detection.Ssd.feature_extractor', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='box_coder', full_name='rastervision.protos.tf_object_detection.Ssd.box_coder', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='matcher', full_name='rastervision.protos.tf_object_detection.Ssd.matcher', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='similarity_calculator', full_name='rastervision.protos.tf_object_detection.Ssd.similarity_calculator', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='encode_background_as_zeros', full_name='rastervision.protos.tf_object_detection.Ssd.encode_background_as_zeros', index=6,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='negative_class_weight', full_name='rastervision.protos.tf_object_detection.Ssd.negative_class_weight', index=7,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='box_predictor', full_name='rastervision.protos.tf_object_detection.Ssd.box_predictor', index=8,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='anchor_generator', full_name='rastervision.protos.tf_object_detection.Ssd.anchor_generator', index=9,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='post_processing', full_name='rastervision.protos.tf_object_detection.Ssd.post_processing', index=10,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='normalize_loss_by_num_matches', full_name='rastervision.protos.tf_object_detection.Ssd.normalize_loss_by_num_matches', index=11,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=True,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='normalize_loc_loss_by_codesize', full_name='rastervision.protos.tf_object_detection.Ssd.normalize_loc_loss_by_codesize', index=12,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='loss', full_name='rastervision.protos.tf_object_detection.Ssd.loss', index=13,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='freeze_batchnorm', full_name='rastervision.protos.tf_object_detection.Ssd.freeze_batchnorm', index=14,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inplace_batchnorm_update', full_name='rastervision.protos.tf_object_detection.Ssd.inplace_batchnorm_update', index=15,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='weight_regression_loss_by_score', full_name='rastervision.protos.tf_object_detection.Ssd.weight_regression_loss_by_score', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='use_expected_classification_loss_under_sampling', full_name='rastervision.protos.tf_object_detection.Ssd.use_expected_classification_loss_under_sampling', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='minimum_negative_sampling', full_name='rastervision.protos.tf_object_detection.Ssd.minimum_negative_sampling', index=18,
      number=19, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desired_negative_sampling_ratio', full_name='rastervision.protos.tf_object_detection.Ssd.desired_negative_sampling_ratio', index=19,
      number=20, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(3),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=645,
  serialized_end=1817,
)


_SSDFEATUREEXTRACTOR = _descriptor.Descriptor(
  name='SsdFeatureExtractor',
  full_name='rastervision.protos.tf_object_detection.SsdFeatureExtractor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='rastervision.protos.tf_object_detection.SsdFeatureExtractor.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='depth_multiplier', full_name='rastervision.protos.tf_object_detection.SsdFeatureExtractor.depth_multiplier', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='min_depth', full_name='rastervision.protos.tf_object_detection.SsdFeatureExtractor.min_depth', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=16,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='conv_hyperparams', full_name='rastervision.protos.tf_object_detection.SsdFeatureExtractor.conv_hyperparams', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='override_base_feature_extractor_hyperparams', full_name='rastervision.protos.tf_object_detection.SsdFeatureExtractor.override_base_feature_extractor_hyperparams', index=4,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pad_to_multiple', full_name='rastervision.protos.tf_object_detection.SsdFeatureExtractor.pad_to_multiple', index=5,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='use_explicit_padding', full_name='rastervision.protos.tf_object_detection.SsdFeatureExtractor.use_explicit_padding', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='use_depthwise', full_name='rastervision.protos.tf_object_detection.SsdFeatureExtractor.use_depthwise', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fpn', full_name='rastervision.protos.tf_object_detection.SsdFeatureExtractor.fpn', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1820,
  serialized_end=2226,
)


_FEATUREPYRAMIDNETWORKS = _descriptor.Descriptor(
  name='FeaturePyramidNetworks',
  full_name='rastervision.protos.tf_object_detection.FeaturePyramidNetworks',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_level', full_name='rastervision.protos.tf_object_detection.FeaturePyramidNetworks.min_level', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='max_level', full_name='rastervision.protos.tf_object_detection.FeaturePyramidNetworks.max_level', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=7,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='additional_layer_depth', full_name='rastervision.protos.tf_object_detection.FeaturePyramidNetworks.additional_layer_depth', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=256,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2228,
  serialized_end=2333,
)

_SSD.fields_by_name['image_resizer'].message_type = rastervision_dot_protos_dot_tf__object__detection_dot_image__resizer__pb2._IMAGERESIZER
_SSD.fields_by_name['feature_extractor'].message_type = _SSDFEATUREEXTRACTOR
_SSD.fields_by_name['box_coder'].message_type = rastervision_dot_protos_dot_tf__object__detection_dot_box__coder__pb2._BOXCODER
_SSD.fields_by_name['matcher'].message_type = rastervision_dot_protos_dot_tf__object__detection_dot_matcher__pb2._MATCHER
_SSD.fields_by_name['similarity_calculator'].message_type = rastervision_dot_protos_dot_tf__object__detection_dot_region__similarity__calculator__pb2._REGIONSIMILARITYCALCULATOR
_SSD.fields_by_name['box_predictor'].message_type = rastervision_dot_protos_dot_tf__object__detection_dot_box__predictor__pb2._BOXPREDICTOR
_SSD.fields_by_name['anchor_generator'].message_type = rastervision_dot_protos_dot_tf__object__detection_dot_anchor__generator__pb2._ANCHORGENERATOR
_SSD.fields_by_name['post_processing'].message_type = rastervision_dot_protos_dot_tf__object__detection_dot_post__processing__pb2._POSTPROCESSING
_SSD.fields_by_name['loss'].message_type = rastervision_dot_protos_dot_tf__object__detection_dot_losses__pb2._LOSS
_SSDFEATUREEXTRACTOR.fields_by_name['conv_hyperparams'].message_type = rastervision_dot_protos_dot_tf__object__detection_dot_hyperparams__pb2._HYPERPARAMS
_SSDFEATUREEXTRACTOR.fields_by_name['fpn'].message_type = _FEATUREPYRAMIDNETWORKS
DESCRIPTOR.message_types_by_name['Ssd'] = _SSD
DESCRIPTOR.message_types_by_name['SsdFeatureExtractor'] = _SSDFEATUREEXTRACTOR
DESCRIPTOR.message_types_by_name['FeaturePyramidNetworks'] = _FEATUREPYRAMIDNETWORKS

Ssd = _reflection.GeneratedProtocolMessageType('Ssd', (_message.Message,), dict(
  DESCRIPTOR = _SSD,
  __module__ = 'rastervision.protos.tf_object_detection.ssd_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.Ssd)
  ))
_sym_db.RegisterMessage(Ssd)

SsdFeatureExtractor = _reflection.GeneratedProtocolMessageType('SsdFeatureExtractor', (_message.Message,), dict(
  DESCRIPTOR = _SSDFEATUREEXTRACTOR,
  __module__ = 'rastervision.protos.tf_object_detection.ssd_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.SsdFeatureExtractor)
  ))
_sym_db.RegisterMessage(SsdFeatureExtractor)

FeaturePyramidNetworks = _reflection.GeneratedProtocolMessageType('FeaturePyramidNetworks', (_message.Message,), dict(
  DESCRIPTOR = _FEATUREPYRAMIDNETWORKS,
  __module__ = 'rastervision.protos.tf_object_detection.ssd_pb2'
  # @@protoc_insertion_point(class_scope:rastervision.protos.tf_object_detection.FeaturePyramidNetworks)
  ))
_sym_db.RegisterMessage(FeaturePyramidNetworks)


# @@protoc_insertion_point(module_scope)
